@@ -34,7 +34,7 @@ require "sexp"
 class SexpProcessor
 
   # duh
-  VERSION = "4.11.0"
+  VERSION = "4.17.0"
 
   ##
   # Automatically shifts off the Sexp type before handing the
@@ -317,7 +317,7 @@ class SexpProcessor
 
   def assert_type list, typ
     raise SexpTypeError, "Expected type #{typ.inspect} in #{list.inspect}" if
-      not Array === list or list.first != typ
+      not Array === list or list.sexp_type != typ
   end
 
   def error_handler type, exp = nil # :nodoc:
